//=============================================================================
// CleanSlate.js
//=============================================================================

/*:
 * @plugindesc Optionally disables the title screen or the menu screen.
 * @author NoTaku
 *
 * @param Disable Title Screen
 * @desc Skips the title screen and goes straight into a new game. 0: Show Title, 1: Skip Title
 * @default 1
 *
 * @param Disable Menu Screen
 * @desc Immediately disables the menu screen on game start. 0: Allow Menu, 1: Disable Menu
 * @default 1
 *
 * @help This plugin does not provide plugin commands.
 */

(function() {
    var parameters = PluginManager.parameters('CleanSlate');
    var disableTitleScreen = Number(parameters['Disable Title Screen'] || 1);
    var disableMenuScreen = Number(parameters['Disable Menu Screen'] || 1);

    if(disableTitleScreen) {
        Scene_Boot.prototype.start = function() {
             Scene_Base.prototype.start.call(this);
            SoundManager.preloadImportantSounds();
            if (DataManager.isBattleTest()) {
                DataManager.setupBattleTest();
                SceneManager.goto(Scene_Battle);
            } else if (DataManager.isEventTest()) {
                DataManager.setupEventTest();
                SceneManager.goto(Scene_Map);
            } else {
                this.checkPlayerLocation();
                DataManager.setupNewGame();
                SceneManager.goto(Scene_Map);
            }
            this.updateDocumentTitle();
        };
    }

    if(disableMenuScreen) {
        var _DataManager_createGameObjects = DataManager.createGameObjects;
        DataManager.createGameObjects = function() {
            _DataManager_createGameObjects.call(this);
            $gameSystem.disableMenu();
        };
    }
})();